@@ -1,11 +1,17 @@
-from b3d.aws import helpers
+"""
+IAM helper functions
+"""
 from typing import List, Dict, Tuple
 import boto3
 import b3q
+from b3d.aws import helpers
 
 
 @helpers.attempt_api_call_multiple_times
 def delete_policy(cl: boto3.client, policy_arn: str, dry: bool) -> dict:
+    """
+    Delete a policy
+    """
 
     if dry:
         return helpers.dry_run_success_resp()
@@ -16,18 +22,27 @@ def delete_policy(cl: boto3.client, policy_arn: str, dry: bool) -> dict:
 
 
 def get_policy(cl: boto3.client, policy_arn: str) -> dict:
+    """
+    Describe a policy, if it exists
+    """
 
     resp = helpers.make_call_catch_err(cl.get_policy, PolicyArn=policy_arn)
     return None if resp["ResponseMetadata"]["HTTPStatusCode"] != 200 else resp
 
 
 def get_all_policies(cl: boto3.client, scope: str = "Local", prefix: str = "/"):
+    """
+    Get all policies in some region
+    """
     return list(b3q.get(
         cl.list_policies, attribute="Policies", arguments={"PathPrefix": prefix, "Scope": scope}
     ))
 
 
 def policy_has_tags(cl: boto3.client, policy_arn: str, tags: List[Tuple]) -> bool:
+    """
+    Determine whether a policy is associated with any in some list of tag pairs
+    """
 
     policy_data = get_policy(cl, policy_arn)
     if policy_data is None:
@@ -43,6 +58,10 @@ def policy_has_tags(cl: boto3.client, policy_arn: str, tags: List[Tuple]) -> boo
 
 
 def get_all_policy_arns_with_tags(cl: boto3.client, tags: List[Tuple]) -> List[str]:
+    """
+    Get all policies associated with this AWS account that at least one tag from <tags>
+    is attached to
+    """
 
     ret = []
     all_policies = get_all_policies(cl)
@@ -57,12 +76,18 @@ def get_all_policy_arns_with_tags(cl: boto3.client, tags: List[Tuple]) -> List[s
 
 
 def list_entities_policy_attached(cl: boto3.client, policy_arn: str) -> dict:
+    """
+    List all resources that are associated with some policy ARN
+    """
     return helpers.make_call_catch_err(
         cl.list_entities_for_policy, PolicyArn=policy_arn
     )
 
 
 def list_policy_versions(cl: boto3.client, policy_arn: str) -> dict:
+    """
+    List all versions for a policy
+    """
     return helpers.make_call_catch_err(
         cl.list_policy_versions, PolicyArn=policy_arn
     )
@@ -70,6 +95,9 @@ def list_policy_versions(cl: boto3.client, policy_arn: str) -> dict:
 
 @helpers.attempt_api_call_multiple_times
 def delete_policy_version(cl: boto3.client, policy_arn: str, version_id: str, dry: bool) -> dict:
+    """
+    Delete a version of a policy
+    """
 
     if dry:
         return helpers.dry_run_success_resp()
@@ -81,6 +109,9 @@ def delete_policy_version(cl: boto3.client, policy_arn: str, version_id: str, dr
 
 @helpers.attempt_api_call_multiple_times
 def delete_role(cl: boto3.client, role_name: str, dry: bool) -> dict:
+    """
+    Delete a role
+    """
 
     if dry:
         return helpers.dry_run_success_resp()
@@ -92,6 +123,9 @@ def delete_role(cl: boto3.client, role_name: str, dry: bool) -> dict:
 
 @helpers.attempt_api_call_multiple_times
 def delete_role_permissions_boundary(cl: boto3.client, role_name: str, dry: bool) -> dict:
+    """
+    Delete the permissions boundary assocatied with some role, if it exists
+    """
 
     if dry:
         return helpers.dry_run_success_resp()
@@ -103,6 +137,9 @@ def delete_role_permissions_boundary(cl: boto3.client, role_name: str, dry: bool
 
 @helpers.attempt_api_call_multiple_times
 def delete_role_policy(cl: boto3.client, role_name: str, policy_name: str, dry: bool) -> dict:
+    """
+    Delete an inline policy from a role
+    """
 
     if dry:
         return helpers.dry_run_success_resp()
@@ -114,6 +151,9 @@ def delete_role_policy(cl: boto3.client, role_name: str, policy_name: str, dry:
 
 @helpers.attempt_api_call_multiple_times
 def detach_role_policy(cl: boto3.client, role_name: str, policy_arn: str, dry: bool) -> dict:
+    """
+    Detach a policy from a role
+    """
 
     if dry:
         return helpers.dry_run_success_resp()
@@ -124,18 +164,27 @@ def detach_role_policy(cl: boto3.client, role_name: str, policy_arn: str, dry: b
 
 
 def get_role(cl: boto3.client, role_name: str) -> dict:
+    """
+    Describe a role, if it exists
+    """
 
     resp = helpers.make_call_catch_err(cl.get_role, RoleName=role_name)
     return None if resp["ResponseMetadata"]["HTTPStatusCode"] != 200 else resp
 
 
 def get_all_roles(cl: boto3.client, prefix: str = "/") -> List[Dict]:
+    """
+    List all roles associated with this AWS account
+    """
     return list(b3q.get(
         cl.list_roles, attribute="Roles", arguments={"PathPrefix": prefix}
     ))
 
 
 def role_has_permissions_boundary(cl: boto3.client, role_name: str) -> bool:
+    """
+    Determine whether a role has a permissions boundary
+    """
 
     role_data = get_role(cl, role_name)
     if role_data is not None:
@@ -147,12 +196,18 @@ def role_has_permissions_boundary(cl: boto3.client, role_name: str) -> bool:
 
 
 def list_embedded_role_policies(cl: boto3.client, role_name: str):
+    """
+    List all inline policies for a role
+    """
     return helpers.make_call_catch_err(
         cl.list_role_policies, RoleName=role_name
     )
 
 
 def list_attached_role_policies(cl: boto3.client, role_name: str):
+    """
+    List all attached policies for a role
+    """
     return helpers.make_call_catch_err(
         cl.list_attached_role_policies, RoleName=role_name
     )
@@ -197,6 +252,9 @@ def get_all_role_arns_with_tags(cl: boto3.client, tags: List[Tuple]) -> List[str
 
 @helpers.attempt_api_call_multiple_times
 def delete_instance_profile(cl: boto3.client, instance_profile_name: str, dry: bool) -> dict:
+    """
+    Delete an instance profile
+    """
 
     if dry:
         return helpers.dry_run_success_resp()
@@ -208,6 +266,9 @@ def delete_instance_profile(cl: boto3.client, instance_profile_name: str, dry: b
 
 @helpers.attempt_api_call_multiple_times
 def delete_access_key(cl: boto3.client, user_name: str, access_key_id: str, dry: bool) -> dict:
+    """
+    Delete an access key pair associated with an IAM user
+    """
 
     if dry:
         return helpers.dry_run_success_resp()
@@ -218,12 +279,18 @@ def delete_access_key(cl: boto3.client, user_name: str, access_key_id: str, dry:
 
 
 def get_instance_profile(cl: boto3.client, instance_profile_name: str) -> dict:
+    """
+    Describe an instance profile, if it exists
+    """
 
     resp = helpers.make_call_catch_err(cl.get_instance_profile, InstanceProfileName=instance_profile_name)
     return None if resp["ResponseMetadata"]["HTTPStatusCode"] != 200 else resp
 
 
 def get_attached_user_policies(cl: boto3.client, user_name: str) -> List[Dict]:
+    """
+    List all policies attached to a user
+    """
 
     resp = helpers.make_call_catch_err(
         cl.list_attached_user_policies, UserName=user_name
@@ -231,7 +298,21 @@ def get_attached_user_policies(cl: boto3.client, user_name: str) -> List[Dict]:
     return [] if resp["ResponseMetadata"]["HTTPStatusCode"] != 200 else resp.get("AttachedPolicies", [])
 
 
+def get_inline_user_policies(cl: boto3.client, user_name: str) -> List[str]:
+    """
+    List all inline policies attached to a user
+    """
+
+    resp = helpers.make_call_catch_err(
+        cl.list_user_policies, UserName=user_name
+    )
+    return [] if resp["ResponseMetadata"]["HTTPStatusCode"] != 200 else resp.get("PolicyNames", [])
+
+
 def get_user_access_keys(cl: boto3.client, user_name: str) -> List[Dict]:
+    """
+    List all access keys associated with a user
+    """
     resp = helpers.make_call_catch_err(
         cl.list_access_keys, UserName=user_name
     )
@@ -239,6 +320,9 @@ def get_user_access_keys(cl: boto3.client, user_name: str) -> List[Dict]:
 
 
 def get_all_users(cl: boto3.client) -> List[Dict]:
+    """
+    List all users for this AWS account
+    """
     return list(b3q.get(
         cl.list_users, attribute="Users"
     ))
@@ -246,6 +330,9 @@ def get_all_users(cl: boto3.client) -> List[Dict]:
 
 @helpers.attempt_api_call_multiple_times
 def delete_user(cl: boto3.client, user_name: str, dry: bool) -> dict:
+    """
+    Delete a user
+    """
 
     if dry:
         return helpers.dry_run_success_resp()
@@ -256,6 +343,9 @@ def delete_user(cl: boto3.client, user_name: str, dry: bool) -> dict:
 
 
 def get_user(cl: boto3.client, user_name: str) -> dict:
+    """
+    Describe a user, if it exists
+    """
 
     resp = helpers.make_call_catch_err(
         cl.get_user, UserName=user_name
@@ -265,6 +355,9 @@ def get_user(cl: boto3.client, user_name: str) -> dict:
 
 @helpers.attempt_api_call_multiple_times
 def detach_policy_from_user(cl: boto3.client, user_name: str, policy_arn: str, dry: bool):
+    """
+    Detach a policy from a user
+    """
 
     if dry:
         return helpers.dry_run_success_resp()
@@ -274,7 +367,24 @@ def detach_policy_from_user(cl: boto3.client, user_name: str, policy_arn: str, d
     )
 
 
+@helpers.attempt_api_call_multiple_times
+def delete_inline_user_policy(cl: boto3.client, user_name: str, policy_name: str, dry: bool) -> dict:
+    """
+    Delete an inline policy for some user
+    """
+
+    if dry:
+        return helpers.dry_run_success_resp()
+
+    return helpers.make_call_catch_err(
+        cl.delete_user_policy, UserName=user_name, PolicyName=policy_name
+    )
+
+
 def user_has_permissions_boundary(cl: boto3.client, user_name: str) -> bool:
+    """
+    Determine whether a permissions boundary exists for a user
+    """
 
     user_data = get_user(cl, user_name)
 
@@ -306,8 +416,31 @@ def policy_is_permissions_boundary_for_user(cl: boto3.client, user_name: str, po
     return False
 
 
+def policy_is_permissions_boundary_for_role(cl: boto3.client, role_name: str, policy_arn: str) -> bool:
+    """
+    Given some role name and a policy ARN, determine whether that policy ARN is being used as the
+    permissions boundary for that role.
+    """
+
+    role_data = get_role(cl, role_name)
+
+    # If role doesn't exist, return False
+    if role_data["ResponseMetadata"]["HTTPStatusCode"] != 200:
+        return False
+
+    # If role exists and it has a permissions boundary set, compare it to policy_arn
+    if role_data["Role"].get("PermissionsBoundary") is not None:
+        return role_data["Role"]["PermissionsBoundary"].get("PermissionsBoundaryArn") == policy_arn
+
+    # If role exists and no permissions boundary is set, return False
+    return False
+
+
 @helpers.attempt_api_call_multiple_times
-def detach_permissions_boundary_from_user(cl: boto3.client, user_name: str, dry: bool) -> dict:
+def delete_user_permissions_boundary(cl: boto3.client, user_name: str, dry: bool) -> dict:
+    """
+    Delete a permissions boundary from a user
+    """
 
     if dry:
         return helpers.dry_run_success_resp()
@@ -356,6 +489,9 @@ def get_all_user_arns_with_tags(cl: boto3.client, tags: List[Tuple]) -> List[str
 
 @helpers.attempt_api_call_multiple_times
 def detach_policy_from_group(cl: boto3.client, group_name: str, policy_arn: str, dry: bool):
+    """
+    Detach a policy from a group
+    """
 
     if dry:
         return helpers.dry_run_success_resp()
