@@ -1,13 +1,14 @@
+""" Delete procedures for S3 resources """
+from typing import List, Dict
+import boto3
 from b3d.delete import Service
 from b3d import aws
 from b3d.utils import log_msg
-from typing import List, Dict
-import boto3
 
 
 class S3(Service):
     """
-    Container class for S3 resource deletion procedures
+    Container class for S3 resource delete procedures
     """
 
     @staticmethod
@@ -15,6 +16,9 @@ class S3(Service):
         return "s3"
 
     class Bucket(Service.Resource):
+        """
+        Delete procedure for Bucket objects
+        """
 
         @staticmethod
         def extract_resource_id_from_arn(arn: str) -> str:
@@ -31,9 +35,7 @@ class S3(Service):
             ) is not None
 
         @staticmethod
-        def _delete_objects(cl: boto3.client, bucket_name: str, dry: bool) -> dict:
-
-            objects = aws.s3.get_objects_in_bucket(cl, bucket_name)
+        def _delete_objects(cl: boto3.client, bucket_name: str, objects: list, dry: bool) -> dict:
             return log_msg.log_msg_destroy(
                 resource_type="objects",
                 resource_id=" | ".join(objects),
@@ -51,7 +53,9 @@ class S3(Service):
                 return resps
 
             # Remove all objects stored in this bucket
-            resps.append(S3.Bucket._delete_objects(cl, bucket_name, dry))
+            objects = aws.s3.get_objects_in_bucket(cl, bucket_name)
+            if len(objects) > 0:
+                resps.append(S3.Bucket._delete_objects(cl, bucket_name, objects, dry))
 
             # Delete this bucket
             resps.append(
